@@ -50,7 +50,7 @@
 #include <time.h>
 #endif
 
-#include <ntqdir.h>
+#include <tqdir.h>
 
 #include <kdebug.h>
 #include <tdelocale.h>
@@ -134,7 +134,7 @@ TDEIO::filesize_t Ftp::UnknownSize = (TDEIO::filesize_t)-1;
 
 using namespace TDEIO;
 
-extern "C" { KDE_EXPORT int kdemain(int argc, char **argv); }
+extern "C" { TDE_EXPORT int kdemain(int argc, char **argv); }
 
 int kdemain( int argc, char **argv )
 {
